==> unified-doc-util-text-offsets-0.1.6-beta.0.tgz: package/readme.md <==
# unified-doc-util-text-offsets

[**unified-doc**][unified-doc] [hast][hast] utility to add text offsets to text nodes.

## Install

```sh
npm install unified-doc-util-text-offsets
```

## Use

Given a hast tree parsed from some HTML content:

```js
import textOffsets from 'unified-doc-util-text-offsets';

const html = '<blockquote><strong>some</strong>\ncontent</blockquote>';

const hast = {
  type: 'root',
  children: [
    {
      type: 'element',
      tagName: 'blockquote',
      children: [
        {
          type: 'element',
          tagName: 'strong',
          children: [
            {
              type: 'text',
              value: 'some',
            },
          ],
        },
        {
          type: 'text',
          value: '\ncontent',
        },
      ],
    },
  ],
};

console.log(textOffsets(hast));
```

Yields:

```js
const output = {
  type: 'root',
  children: [
    {
      type: 'element',
      tagName: 'blockquote',
      children: [
        {
          type: 'element',
          tagName: 'strong',
          children: [
            {
              type: 'text',
              value: 'some',
              data: {
                textOffset: { start: 0, end: 4 },
              },
            },
          ],
        },
        {
          type: 'text',
          value: '\ncontent',
          data: {
            textOffset: { start: 4, end: 12 },
          },
        },
      ],
    },
  ],
};
```


## API

```ts
function textOffsets(hast: Hast): Hast;
```

Accepts a valid `hast` tree and applies `textOffset` data to text node.  Returns a new tree.

### Interfaces

```ts
interface TextOffset = {
  start: number;
  end: number;
}
```

A `TextOffset` for a `text` node tracks the start and end offset of its text value relative to the `text` representation of the provided `hast` tree.

The following pseudocode should aid this understanding:

```js
const html = '<blockquote><strong>some</strong>\ncontent</blockquote>';
const htmlText = 'some\ncontent';
const textNodes = ['some', '\ncontent'];
const textNodeOffsets = [
  { start: 0, end: 4 },
  { start: 4, end: 12 },
];

const htmlHast = { ... };
const withTextOffsets = textOffsets(htmlHast) // apply textNodesOffsets to relevant text nodes in the hast tree.
```

<!-- Links -->
[hast]: https://github.com/syntax-tree/hast
[unified-doc]: https://github.com/unified-doc/unified-doc

==> unified-doc-util-text-offsets-0.1.7-beta.0.tgz: package/readme.md <==
# unified-doc-util-text-offsets

[**unified-doc**][unified-doc] [hast][hast] utility to add text offsets to text nodes.

## Install

```sh
npm install unified-doc-util-text-offsets
```

## Use

Given a hast tree parsed from some HTML content:

```js
import textOffsets from 'unified-doc-util-text-offsets';

const html = '<blockquote><strong>some</strong>\ncontent</blockquote>';

const hast = {
  type: 'root',
  children: [
    {
      type: 'element',
      tagName: 'blockquote',
      children: [
        {
          type: 'element',
          tagName: 'strong',
          children: [
            {
              type: 'text',
              value: 'some',
            },
          ],
        },
        {
          type: 'text',
          value: '\ncontent',
        },
      ],
    },
  ],
};

console.log(textOffsets(hast));
```

Yields:

```js
const output = {
  type: 'root',
  children: [
    {
      type: 'element',
      tagName: 'blockquote',
      children: [
        {
          type: 'element',
          tagName: 'strong',
          children: [
            {
              type: 'text',
              value: 'some',
              data: {
                textOffset: { start: 0, end: 4 },
              },
            },
          ],
        },
        {
          type: 'text',
          value: '\ncontent',
          data: {
            textOffset: { start: 4, end: 12 },
          },
        },
      ],
    },
  ],
};
```


## API

```ts
function textOffsets(hast: Hast): Hast;
```

Accepts a valid `hast` tree and applies `textOffset` data to text node.  Returns a new tree.

### Interfaces

```ts
interface TextOffset = {
  start: number;
  end: number;
}
```

A `TextOffset` for a `text` node tracks the start and end offset of its text value relative to the `text` representation of the provided `hast` tree.

The following pseudocode should aid this understanding:

```js
const html = '<blockquote><strong>some</strong>\ncontent</blockquote>';
const htmlText = 'some\ncontent';
const textNodes = ['some', '\ncontent'];
const textNodeOffsets = [
  { start: 0, end: 4 }, // from "[some]\ncontent"
  { start: 4, end: 12 }, // from "some[\ncontent]"
];

const htmlHast = { ... };

// apply textNodesOffsets to relevant text nodes in the hast tree.
const withTextOffsets = textOffsets(htmlHast)
```

<!-- Links -->
[hast]: https://github.com/syntax-tree/hast
[unified-doc]: https://github.com/unified-doc/unified-doc
